# bfast-ray


[![image](https://img.shields.io/pypi/v/bfast-ray.svg)](https://pypi.python.org/pypi/bfast-ray)
[![image](https://img.shields.io/conda/vn/conda-forge/bfast-ray.svg)](https://anaconda.org/conda-forge/bfast-ray)


**The bfast-ray package provides a highly-efficient parallel implementation for the `Breaks For Additive Season and Trend (BFASTmonitor) proposed by Verbesselt et al. The implementation is based on Ray**


-   Free software: MIT license
-   Documentation: https://benerain.github.io/bfast-ray
    

## Features

-   TODO
